You're absolutely right — for platforms like **Clearbit Reveal**, there are usually a few _platform-specific steps_ that go beyond just dropping the script. Here's the updated and **complete GTM implementation guide** with integration steps included:

---

## 🧩 Google Tag Manager (GTM) Setup for Website Visitor Intelligence

**Works with: Clearbit Reveal, Leadfeeder, Albacross, etc.**

---

### ✅ Step 1: Sign Up & Access Your Script

Go to your tool’s dashboard (e.g. Clearbit Reveal, Albacross) and:

- Create a new project/site if needed
    
- Copy your **project-specific JavaScript snippet** (often includes an API key or token embedded)
    
- Example (Clearbit Reveal):
    

```html
<script>
  window.clearbit = { key: 'pk_YOUR_PUBLIC_KEY' };
  (function() {
    var s = document.createElement('script');
    s.src = 'https://reveal.clearbit.com/v1/scripts/reveal.js';
    s.async = true;
    document.head.appendChild(s);
  })();
</script>
```

✅ **Do not reuse someone else’s snippet — the key is tied to your account.**

---

### ✅ Step 2: Add the Script to Google Tag Manager

1. Open [Google Tag Manager](https://tagmanager.google.com/)
    
2. Click **Tags > New**
    
3. Choose **Tag Configuration** → **Custom HTML**
    
4. Paste in the full tracking snippet from your provider
    
5. Under **Triggering**, choose:
    
    - `All Pages` (to fire sitewide)
        
    - Or create a custom trigger for **high-intent pages** only (e.g. `/pricing`, `/solutions`)
        

Optional:

- Enable "Support document.write" (only if instructed)
    
- Use tag priority (e.g. set to 10) so it loads early
    

---

### ✅ Step 3: (For Clearbit Reveal) Configure Account Matching Rules

After installing the tag:

1. Go to your Clearbit Reveal dashboard → **Settings**
    
2. Define:
    
    - Domains or pages to track
        
    - Any exclusions (e.g., staging domains)
        
3. Choose what data to collect:
    
    - Company name, industry, employee count, revenue, tech stack, etc.
        
    - Optional: Enable webhook/API integration if you plan to enrich your CRM
        

---

### ✅ Step 4: Exclude Internal or Irrelevant Traffic

To keep your data clean:

- Filter out office IPs via the Reveal/Leadfeeder dashboard
    
- Or create a GTM **custom trigger** that:
    
    - Blocks the tag from firing for internal users (e.g. using a cookie, login role, or IP range)
        

---

### ✅ Step 5: Preview & Publish

1. Use GTM’s **Preview Mode** to test your tag
    
2. Visit your site and check:
    
    - That the tag fired correctly (GTM debug console)
        
    - That the script was loaded (Network tab → filter for `reveal.js`, `albacross.js`, etc.)
        
3. After verifying, **click Publish** in GTM
    

---

### ✅ Step 6: Verify Visitor Data in the Dashboard

In 1–24 hours (depending on platform latency), go back to your visitor intelligence tool and:

- View the list of companies that visited your site
    
- See enriched firmographic info like:
    
    - Name, industry, employee size, technologies used
        
- Configure **notifications**, **webhooks**, or **CRM sync**
    

---

### ✅ Step 7: (Optional) Connect to Your CRM or Slack

Most tools offer integrations for workflows:

- **CRM Sync** (HubSpot, Salesforce, Pipedrive, etc.)
    
- **Slack Alerts** when a target account visits
    
- **Zapier/Make** workflows to automate scoring or routing
    

In Clearbit Reveal, go to:

- Settings → Integrations
    
- Connect your CRM or configure a webhook
    

---


## 📦 Tool-Specific GTM Setup

### 🔹 Clearbit Reveal

- Insert the script via GTM Custom HTML
    
- Set `window.clearbit = { key: 'pk_XXXX' }` with your public key
    
- Loads the hosted `reveal.js` file
    
- No backend required unless enriching CRM data via API
    

### 🔹 Leadfeeder

- Add the `lftracker.js` script from your account
    
- No key needed — script identifies your website passively
    
- Use dashboard to segment by companies and engagement
    

### 🔹 Albacross

- Install their script with your Account ID
    
- Use `_alc("trackPageView")` to log visits
    
- View matched companies and set up workflows via dashboard
    

---


## You may want to consider:
- A **GTM trigger for only firing on key pages**
- A **Zapier automation recipe** for passing visitor data into Slack or your CRM
